@@ -8,7 +8,6 @@ from collections import namedtuple
 import logging
 import os
 import re
-import sys
 import warnings
 
 from git.cmd import (
@@ -40,11 +39,6 @@ import gitdb
 
 log = logging.getLogger(__name__)
 
-DefaultDBType = GitCmdObjectDB
-if sys.version_info[:2] < (2, 5):     # python 2.4 compatibility
-    DefaultDBType = GitCmdObjectDB
-# END handle python 2.4
-
 BlameEntry = namedtuple('BlameEntry', ['commit', 'linenos', 'orig_path', 'orig_linenos'])
 
 
@@ -88,7 +82,7 @@ class Repo(object):
     # Subclasses may easily bring in their own custom types by placing a constructor or type here
     GitCommandWrapperType = Git
 
-    def __init__(self, path=None, odbt=DefaultDBType, search_parent_directories=False, expand_vars=True):
+    def __init__(self, path=None, odbt=GitCmdObjectDB, search_parent_directories=False, expand_vars=True):
         """Create a new Repo instance
 
         :param path:
@@ -203,15 +197,23 @@ class Repo(object):
     def __del__(self):
         try:
             self.close()
-        except:
+        except Exception:
             pass
 
     def close(self):
         if self.git:
             self.git.clear_cache()
-            gc.collect()
+            # Tempfiles objects on Windows are holding references to
+            # open files until they are collected by the garbage
+            # collector, thus preventing deletion.
+            # TODO: Find these references and ensure they are closed
+            # and deleted synchronously rather than forcing a gc
+            # collection.
+            if is_win:
+                gc.collect()
             gitdb.util.mman.collect()
-            gc.collect()
+            if is_win:
+                gc.collect()
 
     def __eq__(self, rhs):
         if isinstance(rhs, Repo):
@@ -483,15 +485,15 @@ class Repo(object):
     def iter_commits(self, rev=None, paths='', **kwargs):
         """A list of Commit objects representing the history of a given ref/commit
 
-        :parm rev:
+        :param rev:
             revision specifier, see git-rev-parse for viable options.
             If None, the active branch will be used.
 
-        :parm paths:
+        :param paths:
             is an optional path or a list of paths to limit the returned commits to
             Commits that do not contain that path or the paths will not be returned.
 
-        :parm kwargs:
+        :param kwargs:
             Arguments to be passed to git-rev-list - common ones are
             max_count and skip
 
@@ -517,7 +519,7 @@ class Repo(object):
             raise ValueError("Please specify at least two revs, got only %i" % len(rev))
         # end handle input
 
-        res = list()
+        res = []
         try:
             lines = self.git.merge_base(*rev, **kwargs).splitlines()
         except GitCommandError as err:
@@ -578,12 +580,12 @@ class Repo(object):
                 alts = f.read().decode(defenc)
             return alts.strip().splitlines()
         else:
-            return list()
+            return []
 
     def _set_alternates(self, alts):
         """Sets the alternates
 
-        :parm alts:
+        :param alts:
             is the array of string paths representing the alternates at which
             git should look for objects, i.e. /home/user/repo/.git/objects
 
@@ -662,7 +664,7 @@ class Repo(object):
                                **kwargs)
         # Untracked files preffix in porcelain mode
         prefix = "?? "
-        untracked_files = list()
+        untracked_files = []
         for line in proc.stdout:
             line = line.decode(defenc)
             if not line.startswith(prefix):
@@ -693,7 +695,7 @@ class Repo(object):
         Unlike .blame(), this does not return the actual file's contents, only
         a stream of BlameEntry tuples.
 
-        :parm rev: revision specifier, see git-rev-parse for viable options.
+        :param rev: revision specifier, see git-rev-parse for viable options.
         :return: lazy iterator of BlameEntry tuples, where the commit
                  indicates the commit to blame for the line, and range
                  indicates a span of line numbers in the resulting file.
@@ -702,7 +704,7 @@ class Repo(object):
         should get a continuous range spanning all line numbers in the file.
         """
         data = self.git.blame(rev, '--', file, p=True, incremental=True, stdout_as_string=False, **kwargs)
-        commits = dict()
+        commits = {}
 
         stream = (line for line in data.split(b'\n') if line)
         while True:
@@ -714,7 +716,7 @@ class Repo(object):
             if hexsha not in commits:
                 # Now read the next few lines and build up a dict of properties
                 # for this commit
-                props = dict()
+                props = {}
                 while True:
                     line = next(stream)
                     if line == b'boundary':
@@ -755,7 +757,7 @@ class Repo(object):
     def blame(self, rev, file, incremental=False, **kwargs):
         """The blame information for the given file at the given revision.
 
-        :parm rev: revision specifier, see git-rev-parse for viable options.
+        :param rev: revision specifier, see git-rev-parse for viable options.
         :return:
             list: [git.Commit, list: [<line>]]
             A list of tuples associating a Commit object with a list of lines that
@@ -765,8 +767,8 @@ class Repo(object):
             return self.blame_incremental(rev, file, **kwargs)
 
         data = self.git.blame(rev, '--', file, p=True, stdout_as_string=False, **kwargs)
-        commits = dict()
-        blames = list()
+        commits = {}
+        blames = []
         info = None
 
         keepends = True
@@ -861,7 +863,7 @@ class Repo(object):
         return blames
 
     @classmethod
-    def init(cls, path=None, mkdir=True, odbt=DefaultDBType, expand_vars=True, **kwargs):
+    def init(cls, path=None, mkdir=True, odbt=GitCmdObjectDB, expand_vars=True, **kwargs):
         """Initialize a git repository at the given path if specified
 
         :param path:
@@ -869,7 +871,7 @@ class Repo(object):
             or None in which case the repository will be created in the current
             working directory
 
-        :parm mkdir:
+        :param mkdir:
             if specified will create the repository directory if it doesn't
             already exists. Creates the directory with a mode=0755.
             Only effective if a path is explicitly given
@@ -884,7 +886,7 @@ class Repo(object):
             can lead to information disclosure, allowing attackers to
             access the contents of environment variables
 
-        :parm kwargs:
+        :param kwargs:
             keyword arguments serving as additional options to the git-init command
 
         :return: ``git.Repo`` (the newly created repo)"""
@@ -905,6 +907,10 @@ class Repo(object):
 
         odbt = kwargs.pop('odbt', odb_default_type)
 
+        # when pathlib.Path or other classbased path is passed
+        if not isinstance(path, str):
+            path = str(path)
+
         ## A bug win cygwin's Git, when `--bare` or `--separate-git-dir`
         #  it prepends the cwd or(?) the `url` into the `path, so::
         #        git clone --bare  /cygwin/d/foo.git  C:\\Work
@@ -918,9 +924,9 @@ class Repo(object):
         if sep_dir:
             kwargs['separate_git_dir'] = Git.polish_url(sep_dir)
         proc = git.clone(Git.polish_url(url), clone_path, with_extended_output=True, as_process=True,
-                         v=True, **add_progress(kwargs, git, progress))
+                         v=True, universal_newlines=True, **add_progress(kwargs, git, progress))
         if progress:
-            handle_process_output(proc, None, progress.new_message_handler(), finalize_process)
+            handle_process_output(proc, None, progress.new_message_handler(), finalize_process, decode_streams=False)
         else:
             (stdout, stderr) = proc.communicate()
             log.debug("Cmd(%s)'s unused stdout: %s", getattr(proc, 'args', ''), stdout)
@@ -931,12 +937,16 @@ class Repo(object):
         if not osp.isabs(path) and git.working_dir:
             path = osp.join(git._working_dir, path)
 
+        repo = cls(path, odbt=odbt)
+
+        # retain env values that were passed to _clone()
+        repo.git.update_environment(**git.environment())
+
         # adjust remotes - there may be operating systems which use backslashes,
         # These might be given as initial paths, but when handling the config file
         # that contains the remote from which we were clones, git stops liking it
         # as it will escape the backslashes. Hence we undo the escaping just to be
         # sure
-        repo = cls(path, odbt=odbt)
         if repo.remotes:
             with repo.remotes[0].config_writer as writer:
                 writer.set_value('url', Git.polish_url(repo.remotes[0].url))
@@ -974,10 +984,10 @@ class Repo(object):
     def archive(self, ostream, treeish=None, prefix=None, **kwargs):
         """Archive the tree at the given revision.
 
-        :parm ostream: file compatible stream object to which the archive will be written as bytes
-        :parm treeish: is the treeish name/id, defaults to active branch
-        :parm prefix: is the optional prefix to prepend to each filename in the archive
-        :parm kwargs: Additional arguments passed to git-archive
+        :param ostream: file compatible stream object to which the archive will be written as bytes
+        :param treeish: is the treeish name/id, defaults to active branch
+        :param prefix: is the optional prefix to prepend to each filename in the archive
+        :param kwargs: Additional arguments passed to git-archive
 
             * Use the 'format' argument to define the kind of format. Use
               specialized ostreams to write any format supported by python.
@@ -991,7 +1001,7 @@ class Repo(object):
         if prefix and 'prefix' not in kwargs:
             kwargs['prefix'] = prefix
         kwargs['output_stream'] = ostream
-        path = kwargs.pop('path', list())
+        path = kwargs.pop('path', [])
         if not isinstance(path, (tuple, list)):
             path = [path]
         # end assure paths is list
